.. _install-rdo:

Install for Red Hat Enterprise Linux, Fedora, and CentOS
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
This section describes how to install the Networking-Ansible ML2 Driver
for Red Hat Enterprise Linux 7, Fedora, and CentOS 7.


Install components
------------------

#. Install the packages:

   .. code-block:: console

      # yum install python2-networking-ansible
